# Methods List

<table>
	<tr align="center">
		<th>Title</th>
		<th>Code</th>
		<th>Ratio(Recommended)</th>
		<th>Ratio(Lower Limit)</th>
		<th>Ratio(Upper Limit)</th>
		<th>Water(g)</th>
		<th>Version</th>
	</tr>
	<tr align="center">
		<td>Custom</td>
		<td><code>custom</code></td>
		<td>1/17</td>
		<td>--</td>
		<td>--</td>
		<td>240</td>
		<td>>=0.1</td>
	</tr>
	<tr align="center">
		<td>V60</td>
		<td><code>v60</code></td>
		<td>3/50</td>
		<td>1/18</td>
		<td>1/14</td>
		<td>250</td>
		<td>>=0.1</td>
	</tr>
	<tr align="center">
		<td>Chemex</td>
		<td><code>chemex</code></td>
		<td>1/15</td>
		<td>1/21</td>
		<td>1/10</td>
		<td>240</td>
		<td>>=0.1</td>
	</tr>
	<tr align="center">
		<td>Espresso</td>
		<td><code>espresso</code></td>
		<td>1/2</td>
		<td>1/2.5</td>
		<td>1/1.5</td>
		<td>36</td>
		<td>>=0.1</td>
	</tr>
	<tr align="center">
		<td>French press</td>
		<td><code>french-press</code></td>
		<td>1/15</td>
		<td>1/18</td>
		<td>1/12</td>
		<td>120</td>
		<td>>=0.1</td>
	</tr>
	<tr align="center">
		<td>Siphon</td>
		<td><code>siphon</code></td>
		<td>1/15</td>
		<td>1/16</td>
		<td>1/12</td>
		<td>240</td>
		<td>>=0.1</td>
	</tr>
	<tr align="center">
		<td>Pour-over</td>
		<td><code>pour-over</code></td>
		<td>1/15</td>
		<td>1/16</td>
		<td>1/14</td>
		<td>240</td>
		<td>>=0.2</td>
	</tr>
	<tr align="center">
		<td>Auto drip</td>
		<td><code>auto-drip</code></td>
		<td>1/16</td>
		<td>1/17</td>
		<td>1/14</td>
		<td>128</td>
		<td>>=0.2</td>
	</tr>
	<tr align="center">
		<td>Cold brew</td>
		<td><code>cold-brew</code></td>
		<td>1/11</td>
		<td>1/15</td>
		<td>1/8</td>
		<td>242</td>
		<td>>=0.2</td>
	</tr>
	<tr align="center">
		<td>Cold brew concentrate</td>
		<td><code>cold-brew-conc</code></td>
		<td>1/5</td>
		<td>1/6</td>
		<td>1/4</td>
		<td>120</td>
		<td>>=0.2</td>
	</tr>
	<tr align="center">
		<td>Moka pot</td>
		<td><code>moka-pot</code></td>
		<td>1/10</td>
		<td>1/12</td>
		<td>1/7</td>
		<td>60</td>
		<td>>=0.2</td>
	</tr>
	<tr align="center">
		<td>Ristretto</td>
		<td><code>ristretto</code></td>
		<td>1/1</td>
		<td>1/1.5</td>
		<td>1/1</td>
		<td>18</td>
		<td>>=0.3</td>
	</tr>
	<tr align="center">
		<td>Lungo</td>
		<td><code>lungo</code></td>
		<td>1/4</td>
		<td>1/4</td>
		<td>1/2.5</td>
		<td>72</td>
		<td>>=0.3</td>
	</tr>
	<tr align="center">
		<td>Turkish</td>
		<td><code>turkish</code></td>
		<td>1/10</td>
		<td>1/12</td>
		<td>1/8</td>
		<td>50</td>
		<td>>=0.3</td>
	</tr>
	<tr align="center">
		<td>Cupping</td>
		<td><code>cupping</code></td>
		<td>11/200</td>
		<td>1/19</td>
		<td>1/17</td>
		<td>150</td>
		<td>>=0.3</td>
	</tr>
	<tr align="center">
		<td>AeroPress standard</td>
		<td><code>aero-press</code></td>
		<td>1/15</td>
		<td>1/18</td>
		<td>1/12</td>
		<td>135</td>
		<td>>=0.4</td>
	</tr>
	<tr align="center">
		<td>AeroPress concentrate</td>
		<td><code>aero-press-conc</code></td>
		<td>1/6</td>
		<td>1/7</td>
		<td>1/5</td>
		<td>90</td>
		<td>>=0.4</td>
	</tr>
	<tr align="center">
		<td>AeroPress inverted</td>
		<td><code>aero-press-inv</code></td>
		<td>1/12</td>
		<td>1/14</td>
		<td>1/10</td>
		<td>132</td>
		<td>>=0.4</td>
	</tr>
	<tr align="center">
		<td>Steep-and-release</td>
		<td><code>steep-and-release</code></td>
		<td>1/16</td>
		<td>1/17</td>
		<td>1/14</td>
		<td>255</td>
		<td>>=0.4</td>
	</tr>
</table>


